#ifndef __QUADRATURESHELLFE_H
#define __QUADRATURESHELLFE_H

namespace shellFE {


//! Different quadrature types for triangular meshes
// CenterQuadrature
// template <typename RealType>
// class CenterQuadrature {
// public:
//   enum { numQuadPoints = 1 };
// 
//   inline const DomVecType& getRefCoord ( int ) const  {
//     static const DomVecType c ( 1. / 3., 1. / 3. );
//     return c;
//   }
// 
//   inline RealType getWeight ( int ) const {
//     return 1.;
//   }
// };
// 
// // TriQuadrature
// template <typename RealType>
// class TriQuadrature {
// public:
//   enum { numQuadPoints = 3 };
// 
//   inline const DomVecType& getRefCoord ( int quadpoint ) const  {
//     static const DomVecType c[3] = {
//                                               DomVecType ( 1. / 6., 1. / 6. ),
//                                               DomVecType ( 1. / 6., 2. / 3. ),
//                                               DomVecType ( 2. / 3., 1. / 6. )
//                                             };
//     return c[quadpoint];
//   }
// 
//   inline RealType getWeight ( int ) const {
//     return 1. / 3.;
//   }
// };
// 

template <typename RealType, typename DomVecType>
class CenterOfMassQuadrature {
public:
  enum { numQuadPoints = 1};

  inline const DomVecType& getRefCoord ( int quadpoint ) const  {
    static const DomVecType c[1] = { DomVecType ( 1./3., 1./3. ) };
    return c[quadpoint];
  }

  inline RealType getWeight ( int ) const {
    return 1.;
  }
};

// EdgeQuadrature
template <typename RealType, typename DomVecType>
class EdgeQuadrature {
public:
  enum { numQuadPoints = 3 };

  inline const DomVecType& getRefCoord ( int quadpoint ) const  {
    static const DomVecType c[3] = {    DomVecType ( 1./2., 1./2. ),
                                        DomVecType ( 0., 1./2. ),
                                        DomVecType ( 1./2., 0. )
                                   };
    return c[quadpoint];
  }

  inline RealType getWeight ( int ) const {
    return 1./3.;
  }
};

}

#endif
